summaryrefslogtreecommitdiff
path: root/coverage/plugin.py
diff options
context:
space:
mode:
Diffstat (limited to 'coverage/plugin.py')
-rw-r--r--coverage/plugin.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/coverage/plugin.py b/coverage/plugin.py
index 095b268c..85521e34 100644
--- a/coverage/plugin.py
+++ b/coverage/plugin.py
@@ -329,20 +329,20 @@ class FileReporter(object):
"""
return {}
- def arc_destination_description(self, lineno):
- """Provide an English phrase describing an arc destination.
+ def missing_arc_description(self, start, end):
+ """Provide an English phrase describing a missing arc.
For an arc like (123, 456), it should read well to use the phrase like
this::
- "Line {0} didn't {1}".format(123, arc_destination_description(456))
+ "Line {0} didn't {1}".format(123, missing_arc_description(123, 456))
TODO: say more.
- By default, this simply returns the string "jump to {lineno}".
+ By default, this simply returns the string "jump to {end}".
"""
- return "jump to line {lineno}".format(lineno=lineno)
+ return "jump to line {end}".format(end=end)
def source_token_lines(self):
"""Generate a series of tokenized lines, one for each line in `source`.